sfs.array
=========

.. automodule:: sfs.array

   
   
   .. rubric:: Functions

   .. autosummary::
   
      circular
      concatenate
      cube
      edge
      linear
      linear_diff
      linear_random
      load
      planar
      rectangular
      rounded_edge
      sphere_load
      weights_midpoint
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      ArrayData
   
   

   
   
   